window.Gleam.initSearch([{"doc":"felix","title":"felix","content":"# Felix\n\nAllows user to create a new account or log in by providing a passkey.\nWebAuthN/Fido2 integration.\n\n[![Package Version](https://img.shields.io/hexpm/v/felix)](https://hex.pm/packages/felix)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/felix/)\n\n## JS only\n\nThis library is bindings for the [SimpleWebAuthn server package](https://github.com/MasterKale/SimpleWebAuthn/).\nTherefore it only works on JS server environments.\n\n*I have a prototype for pure Gleam implementation but it is incomplete, get in touch if you need the use of an erlang based implementation.*\n\n## Usage\n\n```sh\nnpm i --save @simplewebauthn/server\ngleam add felix@1\n```\n\n### Verify registration\n\n```gleam\nimport felix/server\n\npub fn verify_registration(response: String) {\n  // generated for each registration and sent to the client earlier\n  let expected_challenge =\n    bit_array.base64_url_encode(&lt;&lt;&quot;secret challenge&quot;&gt;&gt;, False)\n\n  use #(verified, info) &lt;- promise.map_try(server.verify_registration(\n    response: response,\n    expected_challenge: expected_challenge,\n    expected_origin: &quot;http://localhost:8080&quot;,\n    // rpid matches origin without scheme and port\n    expected_rpid: &quot;localhost&quot;,\n    require_user_presence: False,\n    require_user_verification: False,\n  ))\n  case verified {\n    True -&gt;\n      // save the info.public_key in your database\n      Ok(Nil)\n    False -&gt; Error(&quot;invalid&quot;)\n  }\n}\n```\n\n**NOTE:** client side registration can be handled using the [plinth](https://github.com/crowdhailer/plinth) library bindings to the Web credentials API.\n```gleam\nimport plinth/browser/credentials\nimport plinth/browser/credentials/public_key\n\npub fn main(){\n  let assert Ok(container) = credentials.from_navigator()\n  let options =\n    public_key.creation(\n      &lt;&lt;&quot;secret challenge&quot;&gt;&gt;,\n      public_key.ES256,\n      &quot;New service&quot;,\n      &lt;&lt;&quot;my user id&quot;&gt;&gt;,\n      &quot;bob@example.com&quot;,\n      &quot;Bob&quot;,\n    )\n  use response &lt;- promise.try_await(public_key.create(container, options))\n  let response = json.to_string(public_key.to_json(response))\n  // send to server to validate_registration\n}\n```\n\n### Verify authentication\n\n```gleam\nimport felix/server\n\npub fn verify_authentication_test(response) {\n  // generated for each authentication\n  let expected_challenge =\n    bit_array.base64_url_encode(&lt;&lt;&quot;another secret&quot;&gt;&gt;, False)\n  let public_key = todo as &quot;pull from DB&quot;\n\n  use #(verified, info) &lt;- promise.map_try(server.verify_authentication(\n    response: response,\n    expected_challenge: expected_challenge,\n    expected_origin: &quot;http://localhost:8080&quot;,\n    expected_rpid: &quot;localhost&quot;,\n    public_key: public_key,\n    require_user_verification: False,\n  ))\n  verified\n  |&gt; should.be_true\n  info.user_verified\n  |&gt; should.be_true\n  info.credential_device_type\n  |&gt; should.equal(server.MultiDevice)\n  info.credential_backed_up\n  |&gt; should.be_true\n  info.origin\n  |&gt; should.equal(&quot;http://localhost:8080&quot;)\n  info.rp_id\n  |&gt; should.equal(&quot;localhost&quot;)\n  Ok(Nil)\n}\n```\n**NOTE:** client side registration can be handled using the [plinth](https://github.com/crowdhailer/plinth) library bindings to the Web credentials API.\n```gleam\nimport plinth/browser/credentials\nimport plinth/browser/credentials/public_key\n\npub fn main(){\n  let assert Ok(container) = credentials.from_navigator()\n  let options = public_key.request(&lt;&lt;&quot;another secret&quot;&gt;&gt;)\n  use response &lt;- promise.try_await(public_key.get(container, options))\n  let response = json.to_string(public_key.to_json(response))\n  // send to server to validate_authentication\n}\n```\n\n---\n\nFurther documentation can be found at &lt;https://hexdocs.pm/felix&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n\n## Credit\n\nCreated for [EYG](https://eyg.run/), a new integration focused programming language.","url":"index.html"},{"doc":"felix","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\nfelix.main\nfelix main","url":"felix.html#main"},{"doc":"felix","title":"felix","content":"","url":"felix.html"},{"doc":"felix/server","title":"AuthenticationInfo","content":"pub type AuthenticationInfo {\n  AuthenticationInfo(\n    new_counter: Int,\n    user_verified: Bool,\n    credential_device_type: DeviceType,\n    credential_backed_up: Bool,\n    origin: String,\n    rp_id: String,\n  )\n}\n\nAuthenticationInfo(\n  new_counter: Int,\n  user_verified: Bool,\n  credential_device_type: DeviceType,\n  credential_backed_up: Bool,\n  origin: String,\n  rp_id: String,\n)\n\n\nSynonyms:\nfelix/server.AuthenticationInfo\nfelix/server AuthenticationInfo","url":"felix/server.html#AuthenticationInfo"},{"doc":"felix/server","title":"DeviceType","content":"pub type DeviceType {\n  SingleDevice\n  MultiDevice\n}\n\nSingleDevice\n\n\nMultiDevice\n\n\nSynonyms:\nfelix/server.DeviceType\nfelix/server DeviceType","url":"felix/server.html#DeviceType"},{"doc":"felix/server","title":"RegistrationInfo","content":"pub type RegistrationInfo {\n  RegistrationInfo(\n    fmt: String,\n    aaguid: String,\n    credential: WebAuthnCredential,\n    attestation_object: BitArray,\n    user_verified: Bool,\n    credential_device_type: DeviceType,\n    credential_backed_up: Bool,\n    origin: String,\n    rp_id: Option(String),\n  )\n}\n\nRegistrationInfo(\n  fmt: String,\n  aaguid: String,\n  credential: WebAuthnCredential,\n  attestation_object: BitArray,\n  user_verified: Bool,\n  credential_device_type: DeviceType,\n  credential_backed_up: Bool,\n  origin: String,\n  rp_id: Option(String),\n)\n\n\nSynonyms:\nfelix/server.RegistrationInfo\nfelix/server RegistrationInfo","url":"felix/server.html#RegistrationInfo"},{"doc":"felix/server","title":"WebAuthnCredential","content":"pub type WebAuthnCredential {\n  WebAuthnCredential(\n    id: String,\n    public_key: BitArray,\n    counter: Int,\n  )\n}\n\nWebAuthnCredential(\n  id: String,\n  public_key: BitArray,\n  counter: Int,\n)\n\n\nSynonyms:\nfelix/server.WebAuthnCredential\nfelix/server WebAuthnCredential","url":"felix/server.html#WebAuthnCredential"},{"doc":"felix/server","title":"verify_authentication","content":"pub fn verify_authentication(\n  response response: String,\n  expected_challenge expected_challenge: String,\n  expected_origin expected_origin: String,\n  expected_rpid expected_rpid: String,\n  public_key public_key: BitArray,\n  require_user_verification require_user_verification: Bool,\n) -&gt; Promise(Result(#(Bool, AuthenticationInfo), String))\n\nSynonyms:\nfelix/server.verify_authentication\nfelix/server verify_authentication","url":"felix/server.html#verify_authentication"},{"doc":"felix/server","title":"verify_registration","content":"pub fn verify_registration(\n  response response: String,\n  expected_challenge expected_challenge: String,\n  expected_origin expected_origin: String,\n  expected_rpid expected_rpid: String,\n  require_user_presence require_user_presence: Bool,\n  require_user_verification require_user_verification: Bool,\n) -&gt; Promise(Result(#(Bool, Option(RegistrationInfo)), String))\n\nSynonyms:\nfelix/server.verify_registration\nfelix/server verify_registration","url":"felix/server.html#verify_registration"},{"doc":"felix/server","title":"felix/server","content":"","url":"felix/server.html"}]);